#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
Tool to write LaTeX code for the image credits in IPOL articles
"""


# GNU General Public Licence (GPL)
# 
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place, Suite 330, Boston, MA  02111-1307  USA
#

__author__  = '''Miguel Colom'''
__docformat__ = 'plaintext'

import sys
import optparse
import os

def is_image_filename(filename):
  """
  Checks if file name corresponds to an image
  """
  exts = [".JPG", ".JPEG", ".PNG", ".PDF", ".PS", ".EPS"]
  F = filename.upper()
  for ext in exts:
    if F.endswith(ext):
      return True
  #
  return False

def format_filename(filename):
  """
  Removes redundant information from the filename
  """
  if filename.startswith("./"):
    return filename[2:]
  else:
    return filename

def write_image(image):
  """
  Writes the image graphic in LaTeX
  """
  print "\\includegraphics[height=2em]{%s}~" % ((image))


def write_begin_tabular():
  """
  Writes the begin tabular in LaTeX
  """
  print "\\begin{tabular}{l l l l}"

def write_end_tabular():
  """
  Writes the end tabular in LaTeX
  """
  print "\\end{tabular}"

# Parse program arguments
parser = optparse.OptionParser()
parser.add_option('--author', help='Author of the image', default='<AUTHOR>')
parser.add_option('--copyright', help='Copyright of the image', default='CC-BY')
(opts, args) = parser.parse_args()

if len(args) < 1:
  directories = ["."]
else:
  directories = args

# List of images
images = []

# Get the image filenames
for directory in directories:
  for root, dirs, files in os.walk(directory):
    for filename in files:
      if is_image_filename(filename):
        images.append(format_filename(os.path.join(root, filename)))

if len(images) == 0:
  sys.exit(0)

image_num = 1

print "\\section*{Image Credits}"
print "\small"
print "% Please group images with the same credits on a single line."
for image in images:
  #write_image(image, opts.author, opts.copyright)
  write_image(image)
  if image_num % 10 == 0:
    print "\\\\" # Line break
  image_num += 1

# Print the author and copyright
print "%s,~%s" % ((opts.author, opts.copyright))

# Print the (commented) block for the next author
print "% Here it goes the images for the next author"
print "% Please use a different line for each author"
print "%\\\\" # Line break
print "%\\includegraphics[height=2em]{images/image1.png}~"
print "%\\includegraphics[height=2em]{images/image2.png}~"
print "%\\includegraphics[height=2em]{images/image3.png}~"
print "%Other author,~CC-BY"

print "\\normalsize"

